Summary: The GNU libc libraries.
Name: glibc
Version: 2.1.3
Release: 1
Group: System Environment/Libraries
Copyright: LGPL
Packager: Hao Li <hli@wag.caltech.edu>
Source0: ftp://sourceware.cygnus.com/pub/glibc/releases/glibc-%{version}.tar.bz2
Source1: ftp://sourceware.cygnus.com/pub/glibc/releases/glibc-linuxthreads-%{version}.tar.bz2
Source2: http://www.ozemail.com.au/~geoffk/glibc-crypt/glibc-crypt-2.1.1.tar.gz
Source3: nsswitch.conf
Patch0:  glibc-rhpaths.patch
Patch1:  glibc-nscd.patch
Patch2:  glibc-typo.patch
BuildRoot: /var/tmp/%{name}-root
Obsoletes: nscd
Autoreq: false

%description
The glibc package contains standard libraries which are used by
multiple programs on the system. In order to save disk space and
memory, as well as to make upgrading easier, common system code is
kept in one place and shared between programs. This particular package
contains the most important sets of shared libraries: the standard C
library and the standard math library. Without these two libraries, a
Linux system will not function.  The glibc package also contains
national language (locale) support and timezone databases.

WARNING: READ CHANGELOG OF THIS RPM FOR INSTALLATION INSTRUCTIONS !!!
	rpm -qp --changelog glibc-%{version}-%{release}.i386.rpm


%package devel
Summary: Header and object files for development using standard C libraries.
Group: Development/Libraries
Requires: glibc = %{version}, kernel-headers >= 2.2.1
Obsoletes: glibc-profile
Autoreq: true

%description devel
The glibc-devel package contains the header and object files necessary
for developing programs which use the standard C libraries (which are
used by nearly all programs).  If you are developing programs which
will use the standard C libraries, your system needs to have these
standard header and object files available in order to create the
executables.

Install glibc-devel if you are going to develop programs which will
use the standard C libraries.


#%package profile
#Summary: The GNU libc libraries, including support for gprof profiling.
#Group: Development/Libraries
#Requires: glibc = %{version}, kernel-headers >= 2.2.1
#Autoreq: true
#
#%description profile
#The glibc-profile package includes the GNU libc libraries and support
#for profiling using the gprof program.  Profiling is analyzing a
#program's functions to see how much CPU time they use and determining
#which functions are calling other functions during execution.  To use
#gprof to profile a program, your program needs to use the GNU libc
#libraries included in glibc-profile (instead of the standard GNU libc
#libraries included in the glibc package).
#
#If you are going to use the gprof program to profile a program, you'll
#need to install the glibc-profile program.
#
#
#%package -n nscd
#Summary: A Name Service Caching Daemon (nscd).
#Group: System Environment/Daemons
#Autoreq: true
#
#%description -n nscd
#Nscd caches name service lookups and can dramatically improve
#performance with NIS+, and may help with DNS as well. Note that you
#can't use nscd with 2.0 kernels because of bugs in the kernel-side
#thread support. Unfortunately, nscd happens to hit these bugs
#particularly hard.
#
#Install nscd if you need a name service lookup caching daemon, and
#you're not using a version 2.0 kernel.


%prep
%setup -q -a 1 -a 2
%patch0 -p1
%patch1 -p1
%patch2 -p0


%build
# Build it in a seperate directory as suggested in INSTALL
rm -rf i686-linux
mkdir  i686-linux
cd     i686-linux
NCPU=`egrep -c ^processor /proc/cpuinfo`
export PARALLELMFLAGS="-j$NCPU"
CFLAGS="-mcpu=i686 -fstrict-aliasing -O3" \
../configure --prefix=/usr --enable-add-ons
make
cd ..

# Remake info files with --no-split
cd manual
make clean info dvi MAKEINFO="makeinfo --no-split" objdir="../i686-linux"
dvips -t letter -o libc.ps libc.dvi
gzip -9f libc.ps


%install
rm -rf $RPM_BUILD_ROOT
make install_root=$RPM_BUILD_ROOT install -C i686-linux

# install full set of locale data
make install_root=$RPM_BUILD_ROOT objdir="../i686-linux" \
	install-locales -C localedata

# install man pages for linuxthreads
make objdir="../i686-linux" -C linuxthreads/man
mkdir -p $RPM_BUILD_ROOT/usr/man/man3
install -m644 linuxthreads/man/*.3thr $RPM_BUILD_ROOT/usr/man/man3

# gzip info pages
gzip -9f $RPM_BUILD_ROOT/usr/info/libc.info*
rm -f $RPM_BUILD_ROOT/usr/info/dir

# Create symbolic link for libbsd.a
ln -s libbsd-compat.a $RPM_BUILD_ROOT/usr/lib/libbsd.a

# Timezone. "make install" installed default factory time zone of
#   /etc/localtime -> ../usr/share/zoneinfo/Factory
# but I believe much more people will prefer California US timezone
ln -sf ../usr/share/zoneinfo/US/Pacific $RPM_BUILD_ROOT/etc/localtime

# nsswitch.conf for glibc-2.1
install -m644 %{SOURCE3} $RPM_BUILD_ROOT/etc/nsswitch.conf

# This is for ncsd - new in glibc-2.1
install -m644 nscd/nscd.conf $RPM_BUILD_ROOT/etc
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m755 nscd/nscd.init $RPM_BUILD_ROOT/etc/rc.d/init.d/nscd

# The database support
mkdir -p $RPM_BUILD_ROOT/var/db
install -m 644 nss/db-Makefile $RPM_BUILD_ROOT/var/db/Makefile

# strip binaries
strip $RPM_BUILD_ROOT/{sbin,usr/bin,usr/sbin}/* || :

# Now prepare for %doc
mkdir -p rpm_doc/{crypt,linuxthreads}
cp -pr crypt/{COPYING.LIB,ChangeLog,README,README.ufc-crypt,examples} \
				rpm_doc/crypt
cp -pr linuxthreads/{ChangeLog,Changes,Examples,FAQ.html,LICENSE,README,README.Xfree3.2} \
				rpm_doc/linuxthreads
cp -p  db2/README		rpm_doc/README.db2
cp -p  db2/mutex/README		rpm_doc/README.db2.mutex
cp -p  hesiod/README.hesiod	rpm_doc/README.hesiod
cp -p  localedata/README	rpm_doc/README.localedata
cp -p  login/README.utmpd	rpm_doc/README.utmpd
cp -p  timezone/README		rpm_doc/README.timezone


%post
/sbin/ldconfig
/sbin/chkconfig --add nscd

%preun
if [ $1 = 0 ]; then
    /sbin/chkconfig --del nscd
fi

%postun
/sbin/ldconfig


%post devel
/sbin/install-info /usr/info/libc.info.gz /usr/info/dir

%preun devel
if [ $1 = 0 ]; then
    /sbin/install-info --delete /usr/info/libc.info.gz /usr/info/dir
fi


%files
%defattr(-,root,root)
%doc BUGS CONFORMANCE COPYING COPYING.LIB ChangeLog* FAQ INSTALL INTERFACE
%doc NEWS NOTES PROJECTS README README.libm rpm_doc/*
%config /etc/localtime
%config /etc/nscd.conf
%config /etc/nsswitch.conf
%config /etc/rc.d/init.d/nscd
%config /etc/rpc
/lib/*
/sbin/*
/usr/bin/*
/usr/libexec/*
/usr/sbin/*
/usr/share/*
/var/db

%files devel
%defattr(-,root,root)
%doc manual/libc.ps.gz
/usr/include/*
/usr/info/*
/usr/lib/*
/usr/man/man*/*


%clean
rm -rf $RPM_BUILD_ROOT


%changelog
* Wed Aug  4 1999 Hao Li <hli@wag.caltech.edu>
- WARNING: Don't use "rpm -Uvh ..." to upgrade glibc in a running system.
  YOU WILL BE SCREWED UP VERY BADLY. The correct way of doing it is to
  boot the system up with floppies, mount the root partition and the
  partition containing the glibc RPMs, then use "rpm --root ... -Uvh ..."
  to do a chrooted upgrade.

* Wed Aug  4 1999 Hao Li <hli@wag.caltech.edu>
- glibc-2.1.2pre2. Build error unless built in a seperate directory.
- According to INSTALL /usr/libexec/pt_chown is not needed for Linux kernel
  2.1 or newer, but I'll leave it there anyway.
- /etc/localtime and /etc/nsswitch.conf are two files which are most 
  possibly necessary to customize for normal users. People not using
  NIS or NIS+ can disable nscd using "/sbin/chkconfig --del nscd".

